@@ -5,17 +5,21 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 use warnings;
 use strict;
 use utf8;
-use FindBin '$Bin';
 use Carp;
+
+# This Perl version is required because of hashes as errors from
+# JSON::Parse.
+
 use 5.014;
-use JSON::Parse '0.48';
+use JSON::Parse '0.49';
 use C::Tokenize '$comment_re';
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub repair_json
 {
     my ($broken, %options) = @_;
     my $jp = JSON::Parse->new ();
+    # Request a hash response from $jp when there is an error.
     $jp->diagnostics_hash (1);
     my $verbose = $options{verbose};
     my $output = $broken;
@@ -23,7 +27,8 @@ sub repair_json
 	# Try various repairs.  This continues until the JSON is
 	# valid, or none of the repairs have worked. After a
 	# successful repair, "next;" should be used. Falling through
-	# to the end of the loop causes an exit with an error message.
+	# to the end of the while loop which started above causes an
+	# exit with an error message.
 	eval {
 	    $jp->check ($output);
 	};
@@ -119,6 +124,13 @@ sub repair_json
 			next;
 		    }
 		}
+		if ($type eq 'initial state' && $previous !~ /^\s+$/) {
+		    if ($verbose) {
+			print "Deleted trailing garbage $remaining\n";
+		    }
+		    $output = $previous;
+		    next;
+		}
 	    }
 	    if (($type eq 'object' || $type eq 'array') &&
 		$valid_bytes->[ord (',')]) {
